<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Image Carousel Widget
 */

class Image_Carousel_Widget extends \Elementor\Widget_Base {

  public function get_name() {
    return 'medifed-image-carousel';
  }

  public function get_title() {
    return esc_html__('Image Carousel', 'medifed-widget');
  }

  public function get_categories() {
    return ['basic'];
  }


  public function get_style_depends() {
    return ['main-style', 'slick'];
  }

  /**
   * Controls
   */

  protected function register_controls() {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $repeater = new \Elementor\Repeater();

    // Image Gallery
    $repeater->add_control(
      'carousel_image',
      [
        'label' => esc_html__('Carousel Image', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::MEDIA,
        'default' => [
          'url' => \Elementor\Utils::get_placeholder_image_src(),
        ],
      ]
    );


    // Main Title
    $repeater->add_control(
      'image_link',
      [
        'label' => esc_html__('Image Link', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => esc_html__('https://example.com', 'plugin-name'),
        'label_block' => true,
      ]
    );

    // Slide Show
    $this->add_control(
      'slide_show',
      [
        'label' => 'Slide Show',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'max' => 8,
        'default' => 4
      ]
    );

    $this->add_control(
      'list',
      [
        'label' => esc_html__('Carousel List', 'textdomain'),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'image_link' => '#'
          ],
          [
            'image_link' => '#'
          ],
        ],
        'title_field' => 'Carousel Item',
      ]
    );

	
	
	
	
	
    $this->end_controls_section();


    /** Carousel Style */
    $this->start_controls_section(
      'carousel_style',
      [
        'label' => 'Image Style',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
    // Image Width
    $this->add_responsive_control(
      'space_between',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'plugin-name'),
        'size_units' => ['px', 'em', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 400,
          ],
          '%' => [
            'min' => 0,
            'max' => 100,
          ]
        ],
        'devices' => ['desktop', 'tablet', 'mobile'],
        'selectors' => [
          '{{WRAPPER}} .carousel_image' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
    $this->end_controls_section();
  }

  protected function render() {
    $settings = $this->get_settings_for_display();

?>


    <div class="brand2_section">
      <div class="container">
        <div data-slide_show="<?= $settings['slide_show'] ?>" id="slick-<?= $this->get_id() ?>" class="brand_active brand_bg">

          <?php foreach ($settings['list'] as $image) : ?>
            <div class="col-lg-12">
              <div class="img_carsul">
                <a href="<?= $image['image_link'] ?>"><img class="carousel_image" src="<?= esc_attr($image['carousel_image']['url']) ?>" alt=""></a>
              </div>
            </div>
          <?php endforeach ?>

        </div>
      </div>
    </div>

    <?php if (is_admin()) :
      if (!defined('ELEMENTOR_VERSION')) :
        return;
      endif
    ?>
      <script>
         //brand_active
        $("#slick-<?= $this->get_id() ?>").slick({
          dots: false,
          infinite: true,
          autoplay: true,
          speed: 300,
          slidesToShow: <?= $settings['slide_show'] ?>,
          slidesToScroll: 2,
          prevArrow: '<span class="priv_arrow"><i class="icofont-arrow-right"></i></span>',
          nextArrow: '<span class="next_arrow"><i class="icofont-arrow-left"></i></span>',
          arrow: false,
          responsive: [{
              breakpoint: 1200,
              settings: {
                slidesToShow: 4,
                slidesToScroll: 2,
              },
            },
            {
              breakpoint: 992,
              settings: {
                slidesToShow: 3,
                slidesToScroll: 2,
              },
            },
            {
              breakpoint: 767,
              settings: {
                slidesToShow: 1,
                slidesToScroll: 1,
              },
            },
            // You can unslick at a given breakpoint now by adding:
            // settings: "unslick"
            // instead of a settings object
          ],
        });
      </script>
    <?php endif ?>

<?php
  }
}
