<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Posts Widget
 */

class Posts_Widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'medifed-posts';
  }

  public function get_title() {
    return esc_html__('medifed Posts', 'medifed-widget');
  }

  public function get_categories() {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls() {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

	    // Project Style
    $this->add_control(
      'project_style',
      [
        'label' => esc_html__('Project Style', 'textdomain'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1'  => esc_html__('One', 'textdomain'),
          '2' => esc_html__('Two', 'textdomain'),
        ],
      ]
    );
	
    // Post count
    $this->add_control(
      'post_count',
      [
        'label' => 'Number of Post',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'max' => 12,
        'default' => 3
      ]
    );

	
	
    // Icon
    $this->add_control(
      'service_icon',
      [
        'label' => esc_html__('Icon', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'default' => [
          'value' => 'fas fa-circle',
          'library' => 'fa-solid',
        ],
        'recommended' => [
          'fa-solid' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
          'fa-regular' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
        ],
      ]
    );
	
    $this->end_controls_section();


    /**
     * Title Style
     */

    $this->start_controls_section(
      'title_style',
      [
        'label' => 'Main Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Main Title Color
    $this->add_control(
      'title_color',
      [
        'label' => esc_html__('Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .post_widget_title a' => 'color: {{VALUE}} !important',
        ],
      ]
    );

    // Main Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'title_typography',
        'selector' => '{{WRAPPER}} .post_widget_title a',
      ]
    );

    // Main Title Padding
    $this->add_responsive_control(
      'title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .post_widget_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Main Title Margin
    $this->add_responsive_control(
      'title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .post_widget_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();


    /** Meta */

    $this->start_controls_section(
      'meta_style',
      [
        'label' => 'Meta',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Meta Bg Color
    $this->add_control(
      'meta_bg',
      [
        'label' => esc_html__('Background', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .date_all span' => 'background-color: {{VALUE}} !important',
        ],
      ]
    );

    // Meta Typogrphy
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'meta_typography',
        'selector' => '{{WRAPPER}} .date_all span',
      ]
    );

    $this->end_controls_section();


    /** Exerpt */

    $this->start_controls_section(
      'exerpt_style',
      [
        'label' => 'Exerpt',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );


    // Meta Typogrphy
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'exerpt_typography',
        'selector' => '{{WRAPPER}} .post_widget_exerpt',
      ]
    );

    $this->end_controls_section();
  }

  protected function render() {
    $settings = $this->get_settings_for_display();

    // Query Posts
    $args = array(
      'post_type' => 'post',
      'post_status' => 'publish',
      'posts_per_page' => $settings['post_count'],
      'orderby' => 'title',
      'order' => 'ASC',
    );

    $loop = new WP_Query($args);

?>

    <div class="row blog_top">

      <?php while ($loop->have_posts()) : $loop->the_post(); ?>
	  
	  <?php if ($settings['project_style'] == '1') : ?>
	  
        <!--========  blog_part ======== -->
        <div class="col-lg-4 col-md-6">
          <div class="txt_blog_all_area">
            <div class="txt_blg_image">
              <a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
            </div>
            <div class="txt_blog_body">
              <div class="date_all">
                <span><?= get_the_category()[0]->cat_name ?></span>
                <span><a href="#"><i class="far fa-calendar-plus"></i></a><?= the_modified_date() ?></span>
              </div>
              <h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
              <p class="post_widget_exerpt"><?= get_the_excerpt() ?></p>
              <div class="blog_coment">
                <p>Comments (<?= get_comments_number() ?>)</p>
                <div class="star_i">
                  <i class="icofont-star star_color"></i>
                  <i class="icofont-star star_color"></i>
                  <i class="icofont-star star_color"></i>
                  <i class="icofont-star star_color"></i>
                  <i class="icofont-star "></i>
                  <p>(04)</p>
                </div>
              </div>
            </div>
          </div>
        </div>
		
		<?php else : ?>
		
		
		
		 <div class="col-lg-4 col-md-6">
		<div class="txt_blog_all_area style_02">
			 <div class="txt_blg_image">
				 <a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
			 </div>
			 <div class="bl_ic">
				 <?php \Elementor\Icons_Manager::render_icon($settings['service_icon'], ['aria-hidden' => 'true', 'class' => 'service_icon']); ?>
			 </div>
			 <div class="txt_blog_body">
				<div class="txt_blog_inner">
				   <div class="date_all">
					  <span><?= get_the_category()[0]->cat_name ?></span>
					<span><?= the_modified_date() ?></span>
					  <span>- By: Admin,</span>
				   </div>
				   <h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
					<p class="post_widget_exerpt"><?= get_the_excerpt() ?></p>
				</div>
				<div class="blog_coment">
				   <p>Comments (<?= get_comments_number() ?>)</p>
				   <div class="star_i">
					  <i class="icofont-star star_color"></i>
					  <i class="icofont-star star_color"></i>
					  <i class="icofont-star star_color"></i>
					  <i class="icofont-star star_color"></i>
					  <i class="icofont-star "></i>
					  <p>(04)</p>
				   </div>
				</div>
			 </div>
		  </div>
		 </div>
		
		
		<?php endif ?>

      <?php endwhile;
      wp_reset_postdata();
      ?>
    </div>

<?php
  }
}
