<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Pricing Table Widget
 */

class Pricing_Table_Widget extends \Elementor\Widget_Base
{
  public function get_name()
  {
    return 'medifed-pricing';
  }

  public function get_title()
  {
    return esc_html__('medifed Pricing', 'medifed-widget');
  }

  public function get_categories()
  {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls()
  {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    /** Title */
    $this->add_control(
      'pricing_title',
      [
        'label' => 'Title',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'Premium Market'
      ]
    );

    /** Price */
    $this->add_control(
      'price',
      [
        'label' => 'Price',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => '$45'
      ]
    );

    /** Time */
    $this->add_control(
      'pricing_time',
      [
        'label' => 'Time',
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'Month',
        'options' => [
          'Day' => 'Day',
          'Weak' => 'Weak',
          'Month' => 'Month',
          'Year' => 'Year'
        ]
      ]
    );

    // Feature List
    $repeater = new \Elementor\Repeater();

    // Feature Title
		$repeater->add_control(
			'list_title', [
				'label' => esc_html__( 'Title', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Feature Title' , 'plugin-name' ),
				'label_block' => true,
			]
		);

    // Feature Icon
    $repeater->add_control(
			'icon',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-circle',
					'library' => 'fa-solid',
				],
				'recommended' => [
					'fa-solid' => [
						'circle',
						'dot-circle',
						'square-full',
					],
					'fa-regular' => [
						'circle',
						'dot-circle',
						'square-full',
					],
				],
			]
		);

    $this->add_control(
			'feature_list',
			[
				'label' => esc_html__( 'Feature List', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'list_title' => esc_html__( 'Technology and Industry', 'plugin-name' ),
					],
					[
						'list_title' => esc_html__( 'Synced To Cloud Database', 'plugin-name' ),
					],
				],
				'title_field' => '{{{ list_title }}}',
			]
		);

    /** Button Text */
    $this->add_control(
      'pricing_button',
      [
        'label' => 'Button Text',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'Choose Plan'
      ]
    );

    /** Button Url */
    $this->add_control(
      'button_link',
      [
        'label' => esc_html__('Button Link', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::URL,
        'placeholder' => esc_html__('https://your-link.com', 'plugin-name'),
        'options' => ['url', 'is_external', 'nofollow'],
        'default' => [
          'url' => '',
          'is_external' => true,
          'nofollow' => true,
          // 'custom_attributes' => '',
        ],
        'label_block' => true,
      ]
    );

    $this->end_controls_section();


    /**
     * Counter Styles
     */

    $this->start_controls_section(
      'title_style',
      [
        'label' => 'Title Style',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'title_typography',
        'selector' => '{{WRAPPER}} .stxt_pricing_title > h3',
      ]
    );

    /** Title Color */
    $this->add_control(
      'title_color',
      [
        'label' => esc_html__('Title Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .stxt_pricing_title > h3' => 'color: {{VALUE}}',
        ],
      ]
    );

    /** Title Background Color */
    $this->add_control(
      'title_bg_color',
      [
        'label' => esc_html__('Title Background', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .stxt_pricing_title > h3' => 'background-color: {{VALUE}}',
        ],
      ]
    );

	// title Padding
	$this->add_responsive_control(
		'title1_padding',
		[
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'label' => esc_html__( 'Padding', 'plugin-name' ),
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .stxt_pricing_title > h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);
	// title Margin
    $this->add_responsive_control(
      'title1_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .stxt_pricing_title > h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
		
	
	
    $this->end_controls_section();


    /** Price Style */
    $this->start_controls_section(
      'price_style',
      [
        'label' => 'Price Style',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Price Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'price_typography',
        'selector' => '{{WRAPPER}} .stxt_pricing_center > span',
      ]
    );

    /** Price Color */
    $this->add_control(
      'price_color',
      [
        'label' => esc_html__('Price Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .stxt_pricing_center > span' => 'color: {{VALUE}}',
        ],
      ]
    );
	
	 // price Padding
    $this->add_responsive_control(
			'price_padding',
			[
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'label' => esc_html__( 'Padding', 'plugin-name' ),
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .stxt_pricing_center' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
	// price Margin
    $this->add_responsive_control(
      'price_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .stxt_pricing_center' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
		
	
    
    $this->end_controls_section();


    /** Button Style */

    $this->start_controls_section(
      'button_style',
      [
        'label' => 'Button Style',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );


    /** Tabs */

    $this->start_controls_tabs(
      'style_tabs'
    );

    // Normal Tab
    $this->start_controls_tab(
      'style_normal_tab',
      [
        'label' => esc_html__('Normal', 'plugin-name'),
      ]
    );

	    // Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'button_typography',
        'selector' => '{{WRAPPER}} .stxt_btn > a',
      ]
    );

	
    /** Button Text Color */
    $this->add_control(
      'button_text_color',
      [
        'label' => esc_html__('Text Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .stxt_btn > a' => 'color: {{VALUE}}',
        ],
      ]
    );

    /** Button Background Color */
    $this->add_control(
      'button_bg_color',
      [
        'label' => esc_html__('Button Background', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .stxt_btn > a' => 'background-color: {{VALUE}}',
        ],
      ]
    );
	
	  // Button Padding
    $this->add_responsive_control(
			'button_padding',
			[
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'label' => esc_html__( 'Padding', 'plugin-name' ),
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .stxt_btn > a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
	// Button Margin
    $this->add_responsive_control(
      'main_button_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .stxt_btn > a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
		
	

    $this->end_controls_tab();

    // Hover Tab
    $this->start_controls_tab(
      'style_hover_tab',
      [
        'label' => esc_html__('Hover', 'plugin-name'),
      ]
    );

    /** Button Text Color */
    $this->add_control(
      'button_text_color_hover',
      [
        'label' => esc_html__('Text Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .stxt_btn > a:hover' => 'color: {{VALUE}}',
        ],
      ]
    );

    /** Button Background Color */
    $this->add_control(
      'button_bg_color_hover',
      [
        'label' => esc_html__('Button Background', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .stxt_btn > a:hover' => 'background-color: {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_tab();
    $this->end_controls_tabs();

  
    $this->end_controls_section();
  }

  protected function render()
  {
    $settings = $this->get_settings_for_display();

    if ( ! empty( $settings['button_link']['url'] ) ) {
			$this->add_link_attributes( 'button_link', $settings['button_link'] );
		}
?>

    <div class="stxt_pricing_content" style="max-width: 400px; margin:auto">
      <div class="stxt_pricing_title">
        <h3><?= $settings['pricing_title'] ?></h3>
      </div>
      <div class="stxt_pricing_center">
        <span><?= $settings['price'] ?>/</span>
        <div class="month_text">
          <span><?= $settings['pricing_time'] ?></span>
        </div>
      </div>
      <div class="stxt_item_list">
        <ul>
          <?php foreach($settings['feature_list'] as $list): ?>
            <li><span style="margin-right: 5px;"><?php \Elementor\Icons_Manager::render_icon( $list['icon'], [ 'aria-hidden' => 'true' ] ); ?></span><?= $list['list_title'] ?></li>
          <?php endforeach ?>
        </ul>
      </div>
      <div class="stxt_btn">
        <a <?php echo $this->get_render_attribute_string( 'button_link' ); ?> class="tabtn"><?= $settings['pricing_button'] ?></a>
      </div>
    </div>

<?php
  }
}
