<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Section Info Widget
 */

class Section_Info_Widget extends \Elementor\Widget_Base
{
  public function get_name()
  {
    return 'section-info';
  }

  public function get_title()
  {
    return esc_html__('Section Info', 'medifed-widget');
  }

  public function get_categories()
  {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls()
  {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    // Widget Style
    $this->add_control(
      'widget_style',
      [
        'label' => 'Widget Style',
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'one',
        'options' => [
          'one' => 'One',
          'two' => 'Two',
        ]
      ]
    );

    // Show Icon
    $this->add_control(
			'show_icon',
			[
				'label' => esc_html__( 'Show Icon', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

    // Main Title
    $this->add_control(
      'main_title',
      [
        'label' => 'Main Title',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'placeholder' => 'Main title here',
        'default' => 'title 01'
      ]
    );

    // Sub Title
    $this->add_control(
      'sub_title',
      [
        'label' => 'Sub Title',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'placeholder' => 'Sub title here',
        'default' => 'We Are Provide Rent of Best Service.'
      ]
    );

    // Description
    $this->add_control(
      'desc',
      [
        'label' => 'Description',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => "If you are going to use a passage of Lorem Ipsu, you need this be sure there isn't anything embarrassing hidden in the best middle of text. All the Lorem Ipsum generators ."
      ]
    );

    $this->end_controls_section();


    /**
     * Main Title Style
     */

    $this->start_controls_section(
      'main_title_style',
      [
        'label' => 'Main Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Main Title Color
    $this->add_control(
      'main_title_color',
      [
        'label' => esc_html__('Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .section_main_title' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Main Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'main_title_typography',
        'selector' => '{{WRAPPER}} .section_main_title',
      ]
    );

    // Main Title Padding
    $this->add_responsive_control(
      'main_title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_main_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Main Title Margin
    $this->add_responsive_control(
      'main_title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_main_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();



    /**
     * Sub Title Style
     */

    $this->start_controls_section(
      'sub_title_style',
      [
        'label' => 'Sub Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Sub Title Color
    $this->add_control(
      'sub_title_color',
      [
        'label' => esc_html__('Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .section_sub_title' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Sub Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'sub_title_typography',
        'selector' => '{{WRAPPER}} .section_sub_title',
      ]
    );

    // Sub Title Padding
    $this->add_responsive_control(
      'sub_title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_sub_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Sub Title Margin
    $this->add_responsive_control(
      'sub_title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_sub_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();


    /**
     * Description Style
     */

    $this->start_controls_section(
      'desc_style',
      [
        'label' => 'Decription',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Des Color
    $this->add_control(
      'desc_color',
      [
        'label' => esc_html__('Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .section_desc' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Desc Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'desc_typography',
        'selector' => '{{WRAPPER}} .section_desc',
      ]
    );

	// content Width
    $this->add_responsive_control(
      'content_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .t1_top_text p, {{WRAPPER}} .t1_top_title p' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	 
    // Desc Padding
    $this->add_responsive_control(
      'desc_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Desc Margin
    $this->add_responsive_control(
      'desc_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();
  }


  protected function render()
  {
    $settings = $this->get_settings_for_display();

    if ($settings['widget_style'] == 'one') : ?>

      <div class="row">
        <div class="col-lg-12">
          <div class="t1_top_title stly_one">
            <h1 class="section_sub_title"><?= $settings['main_title'] ?></h1>
            <h2 class="section_main_title"><?= $settings['sub_title'] ?></h2>
			<p class="section_desc"> <?= $settings['desc'] ?></p>
          </div>
        </div>
      </div>

    <?php else : ?>

        <div class="t1_top_title text-left">
          <h1 class="section_sub_title"><?= $settings['main_title'] ?></h1>
          <h2 class="section_main_title"><?= $settings['sub_title'] ?></h2>
          <p class="section_desc">
          <?php if('yes' === $settings['show_icon']): ?>
            <img src="<?= plugin_dir_url(__DIR__) ?>/assets/images/title-bar.png" alt="">
          <?php endif ?>
          <?= $settings['desc'] ?></p>
        </div>

		
<?php endif;
  }
}
