<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Team Widget
 */

class Team_Widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'medifed-team';
  }

  public function get_title() {
    return esc_html__('medifed Team', 'medifed-widget');
  }

  public function get_categories() {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls() {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    // Team Style
    $this->add_control(
      'team_style',
      [
        'label' => esc_html__('Team Style', 'textdomain'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1'  => esc_html__('One', 'textdomain'),
          '2' => esc_html__('Two', 'textdomain'),
        ],
      ]
    );

    // Post count
    $this->add_control(
      'post_count',
      [
        'label' => 'Number of Post',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'max' => 12,
        'default' => 3
      ]
    );


    $this->end_controls_section();


	
	 // Box Style
	 $this->start_controls_section(
      'box_style',
      [
        'label' => 'Box Color Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'boxs_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .all_title_team',
      ]
    );
	  // Box Padding 
    $this->add_responsive_control(
      'ser_box_padding',
      [
        'label' => 'Box Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .all_title_team' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Box Margin
    $this->add_responsive_control(
      'ser_box_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .all_title_team' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	 
	/* box shadow */	
	$this->add_group_control(
		\Elementor\Group_Control_Box_Shadow::get_type(),
		[
			'name' => 'box_shadow',
			'label' => esc_html__( 'Box Shadow', 'medifed' ),
			'selector' => '{{WRAPPER}} .all_title_team',
		]
	); 
	 
	$this->end_controls_section();
	
	
	
    /* Title Style */

	
	
    $this->start_controls_section(
      'title_style',
      [
        'label' => 'Main Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Main Title Color
    $this->add_control(
      'title_color',
      [
        'label' => esc_html__('Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .team_main_title a' => 'color: {{VALUE}} !important',
        ],
      ]
    );

    // Main Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'title_typography',
        'selector' => '{{WRAPPER}} .team_main_title a',
      ]
    );

    // Main Title Padding
    $this->add_responsive_control(
      'title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_main_title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Main Title Margin
    $this->add_responsive_control(
      'title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_main_title a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();


    /* Sub Title Style */

    $this->start_controls_section(
      'sub_title_style',
      [
        'label' => 'Sub Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Sub Title Color
    $this->add_control(
      'sub_title_color',
      [
        'label' => esc_html__('Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .team_sub_title' => 'color: {{VALUE}} !important',
        ],
      ]
    );

    // Sub Main Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'sub_title_typography',
        'selector' => '{{WRAPPER}} .team_sub_title',
      ]
    );

    // Sub Title Padding
    $this->add_responsive_control(
      'sub_title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_sub_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Sub Title Margin
    $this->add_responsive_control(
      'sub_title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_sub_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();
  }

  protected function render() {
    $settings = $this->get_settings_for_display();

    // Query Posts
    $args = array(
      'post_type' => 'team',
      'post_status' => 'publish',
      'posts_per_page' => $settings['post_count'],
      'orderby' => 'title',
      'order' => 'ASC',
    );

    $loop = new WP_Query($args);

?>

    <div class="team_section">
      <div class="container">
        <div class="row mr_top">

          <?php while ($loop->have_posts()) : $loop->the_post(); ?>

            <?php if ($settings['team_style'] == '1') : ?>
              <!--========  team_t1_01 ======== -->
              <div class=" col-lg-4 col-md-6">
                <div class=" all_title_team ">
                  <div class="wtx_image_area">
                    <img src="<?= get_the_post_thumbnail_url() ?>" alt="">
                  </div>
                  <div class="wtx_team_content">
                    <div class="wtx_content2 content1_bg_color">
                      <h5 class="team_main_title"><a href="<?= get_post_permalink() ?>"><?= the_title() ?></a></h5>
                      <span class="team_sub_title"><?= get_post_meta(get_the_ID(), '_team_title')[0] ?></span>
                    </div>
                    <div class="team_icon">
                      <i class="fas fa-phone-alt"></i>
                    </div>
                  </div>
                </div>
              </div>

            <?php else : ?>

              <div class=" col-lg-4 col-md-6">
                <div class=" all_title_team team_style2">
                  <div class="wtx_image_area">
                    <img src="<?= get_the_post_thumbnail_url() ?>" alt="">
                  </div>
                  <div class="wtx_team_icon">
                    <?php
                      $socials = get_post_meta(get_the_ID(), '_team_socials', true);
               
                      if($socials):
                    ?>
                      <ul>
                        <?= $socials['facebook'] ? '<li><a href="'. $socials['facebook'] .'"><i class="icofont-facebook"></i></a></li>' : '' ?>
                        <?= $socials['twitter'] ? '<li><a href="'. $socials['twitter'] .'"><i class="icofont-twitter"></i></a></li>' : '' ?>
                        <?= $socials['instagram'] ? '<li><a href="'. $socials['instagram'] .'"><i class="icofont-instagram"></i></a></li>' : '' ?>
                        <?= $socials['google'] ? '<li><a href="'. $socials['google'] .'"><i class="icofont-google-plus"></i></a></li>' : '' ?>
                      </ul>

                    <?php endif ?>

                  </div>
                  <div class="wtx_team_content">
                    <div class="wtx_content2 content1_bg_color">
                      <h5 class="team_main_title"><a href="<?= get_post_permalink() ?>"><?= the_title() ?></a></h5>
                      <span class="team_sub_title"><?= get_post_meta(get_the_ID(), '_team_title')[0] ?></span>
                    </div>
                  </div>
                </div>
              </div>

            <?php endif ?>

          <?php endwhile;
          wp_reset_postdata();
          ?>
        </div>
      </div>
    </div>

<?php
  }
}
